@@ -10,6 +10,7 @@ import ap
 import olt
 from preseem import NetworkMetadataReference, Reference
 from preseem.network_element_update import NetworkElementUpdate
+from preseem_protobuf.network_poller import network_poller_pb2
 from fake_context import FakeContext
 
 #logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
@@ -610,3 +611,19 @@ class TestOLT(unittest.TestCase):
             '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
+
+    def test_offline_ont(self):
+        """An ONT is offline; it is sent in peers but there is no link."""
+        olt = self.setup_simple_network(bridged_macs=False)
+        del olt.module.next_neu.data.interfaces[0].pons[0]
+        del olt.module.next_neu.peers[0].interfaces[0].pons[0]
+        olt.module.next_neu.peers[0].status = network_poller_pb2.ELEMENT_STATUS_OFFLINE
+
+        self.ctx.bridge_mapping_enabled = False
+        self.run_poll()
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 2)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
+        })
